@@ -1,6 +1,7 @@
 import dataclasses
 
 from shopify_client.billing.constants import SubscriptionInterval
+from shopify_client.billing.schema.requests.discount import Discount
 from shopify_client.billing.schema.requests.price import Price
 
 
@@ -8,3 +9,4 @@ from shopify_client.billing.schema.requests.price import Price
 class RecurringPricingDetails:
     interval: SubscriptionInterval
     price: Price
+    discount: Discount
