@@ -6,3 +6,7 @@ class SupportedClient(Enum):
     WEBHOOK = 'webhook'
     SCRIPT_TAG = 'script_tag'
     STORE_PROPERTIES = 'store_properties'
+    PRODUCT = 'product'
+    BULK_OPERATIONS = 'bulk_operations'
+    THEMES = 'themes'
+    APP = 'app'
