@@ -1,9 +1,13 @@
 import shopify
 
+from shopify_client.app import AppClient
 from shopify_client.billing import BillingClient
+from shopify_client.bulk_operations import BulkOperationsClient
 from shopify_client.constants import SupportedClient
+from shopify_client.products import ProductClient
 from shopify_client.script_tag.client import ScriptTagClient
 from shopify_client.store_properties import StorePropertiesClient
+from shopify_client.themes.client import ThemeClient
 from shopify_client.versions import BASE_VERSION
 from shopify_client.webhooks import WebhookClient
 
@@ -13,7 +17,11 @@ class ShopifyClientFactory:
         SupportedClient.BILLING.value: BillingClient,
         SupportedClient.WEBHOOK.value: WebhookClient,
         SupportedClient.SCRIPT_TAG.value: ScriptTagClient,
-        SupportedClient.STORE_PROPERTIES.value: StorePropertiesClient
+        SupportedClient.STORE_PROPERTIES.value: StorePropertiesClient,
+        SupportedClient.PRODUCT.value: ProductClient,
+        SupportedClient.BULK_OPERATIONS.value: BulkOperationsClient,
+        SupportedClient.THEMES.value: ThemeClient,
+        SupportedClient.APP.value: AppClient
     }
 
     def __init__(self, shop, access_token, api_version=BASE_VERSION):
@@ -35,5 +43,21 @@ class ShopifyClientFactory:
     def store_properties(self) -> StorePropertiesClient:
         return self.__get_client(SupportedClient.STORE_PROPERTIES.value)
 
+    @property
+    def products(self) -> ProductClient:
+        return self.__get_client(SupportedClient.PRODUCT.value)
+
+    @property
+    def bulk_operations(self) -> BulkOperationsClient:
+        return self.__get_client(SupportedClient.BULK_OPERATIONS.value)
+
+    @property
+    def themes(self) -> ThemeClient:
+        return self.__get_client(SupportedClient.THEMES.value)
+
+    @property
+    def app(self) -> AppClient:
+        return self.__get_client(SupportedClient.APP.value)
+
     def __get_client(self, client_name: str):
         return self.CLIENT_MAPPING.get(client_name)()
