@@ -14,11 +14,16 @@ class ShopGet:
                 shop {
                     name
                     email
+                    currencyCode
                     plan {
                         displayName
                         shopifyPlus
                         partnerDevelopment
                     }
+                    currencyFormats {
+                        moneyFormat
+                        moneyWithCurrencyInEmailsFormat
+                    }
                 }
             }
         '''
@@ -33,6 +38,8 @@ class ShopGet:
         return {
             'name': shop['name'],
             'email': shop['email'],
+            'currency_code': shop['currencyCode'],
+            'currency_format': shop['currencyFormats']['moneyWithCurrencyInEmailsFormat'] or shop['currencyFormats']['moneyFormat'],
             'plan': {
                 'name': plan['displayName'],
                 'is_shopify_plus': plan['shopifyPlus'],
